/*
 * File: database.h
 * Code: Ben Walding
 * Date: 1 January 1998
 * 
 * 
 * Protected by the GNU Public License v2.0  <distrib>/GPL.LICENSE      
 */

#ifndef _database_h_
#define _database_h_

#include "cdoption.h"
#include "workmandb.h"
#include <malloc.h>

class Album;  /* Pre-declaration so that Track::Track may use Album */

class Track {
public:
  Track(Album *album);
  ~Track(void);
  int min(void) { return (int)(len/60); }
  int sec(void) { return (int)(len%60); }
  char *title() { return titlestr; }
  void setTitle(char *newTitle) { if (!newTitle) return; if (titlestr) free(titlestr); titlestr = strdup(newTitle); }


private:
  char *titlestr;     

public: /* Easier to just allow access */
  int addr;        
  int len;         
  
public:
  Track *next;  
};

class Album {
public:
  Album(void);
  ~Album(void);

  int min() { return (int)(len/60); }
  int sec() { return (int)(len%60); }
  char *title() { return titlestr; }
  char *artist() { return artiststr; }
  void setTitle(char *newTitle) { if (!newTitle) return; if (titlestr) free(titlestr); titlestr = strdup(newTitle); }
  void setArtist(char *newArtist) { if (!newArtist) return; if (artiststr) free(artiststr); artiststr = strdup(newArtist); }

	/* Should be passed a variable to determine search order - XXX XXX XXX */
  int compare(Album& other) { 
	if (global_options.sortartist) 
	  return strcasecmp(artiststr, other.artiststr);
	else
	  return strcasecmp(titlestr, other.titlestr);
  }

private:
  char *titlestr;
  char *artiststr;
public:
  Track *tracks;
  int len;
  int ntracks;
public:
  Album *next;
};

extern Album *album_list;

Album *getAlbumIndex(int value);

void load_database(void);
void clear_database(void);
void sort_database(void);
#endif /*_database_h_*/


